package com.inspect.metadata.montdata.service.impl;

import com.inspect.metadata.montdata.domain.BasedataMontNestRunData;
import com.inspect.metadata.montdata.mapper.BasedataMontNestRunDataMapper;
import com.inspect.metadata.montdata.service.IBasedataMontNestRunDataService;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;

@Service
public class BasedataMontNestRunDataServiceImpl implements IBasedataMontNestRunDataService {
    @Resource
    private BasedataMontNestRunDataMapper basedataMontNestrundataMapper;

    public BasedataMontNestRunData selectBasedataMontNestRunDataByMontNestRunDataId(Long montNestRunDataId) {
        return this.basedataMontNestrundataMapper.selectBasedataMontNestRunDataByMontNestRunDataId(montNestRunDataId);
    }

    public List<BasedataMontNestRunData> selectBasedataMontNestRunDataList(BasedataMontNestRunData basedataMontNestrundata) {
        return this.basedataMontNestrundataMapper.selectBasedataMontNestrundataList(basedataMontNestrundata);
    }

    public int insertBasedataMontNestRunData(BasedataMontNestRunData basedataMontNestrundata) {
        return this.basedataMontNestrundataMapper.insertBasedataMontNestRunData(basedataMontNestrundata);
    }

    public int updateBasedataMontNestRunData(BasedataMontNestRunData basedataMontNestrundata) {
        return this.basedataMontNestrundataMapper.updateBasedataMontNestRunData(basedataMontNestrundata);
    }

    public int deleteBasedataMontNestRunDataByMontNestRunDataIds(Long[] montNestRunDataIds) {
        return this.basedataMontNestrundataMapper.deleteBasedataMontNestRunDataByMontNestRunDataIds(montNestRunDataIds);
    }

    public int deleteBasedataMontNestRunDataByMontNestRunDataId(Long montNestRunDataId) {
        return this.basedataMontNestrundataMapper.deleteBasedataMontNestRunDataByMontNestRunDataId(montNestRunDataId);
    }
}
